@@ -50,16 +50,15 @@ class BtMessageValidator;
 
 class AbstractBtMessage : public BtMessage {
 private:
-  bool sendingInProgress_;
   bool invalidate_;
   bool uploading_;
   cuid_t cuid_;
 
-  std::string name_;
+  const char* name_;
 
-  SharedHandle<PieceStorage> pieceStorage_;
+  PieceStorage* pieceStorage_;
 
-  SharedHandle<Peer> peer_;
+  std::shared_ptr<Peer> peer_;
 
   BtMessageDispatcher* dispatcher_;
 
@@ -69,100 +68,65 @@ private:
 
   PeerConnection* peerConnection_;
 
-  SharedHandle<BtMessageValidator> validator_;
+  std::unique_ptr<BtMessageValidator> validator_;
 
   bool metadataGetMode_;
+
 protected:
-  const SharedHandle<PieceStorage>& getPieceStorage() const
-  {
-    return pieceStorage_;
-  }
+  PieceStorage* getPieceStorage() const { return pieceStorage_; }
 
-  PeerConnection* getPeerConnection() const
-  {
-    return peerConnection_;
-  }
+  PeerConnection* getPeerConnection() const { return peerConnection_; }
 
-  BtMessageDispatcher* getBtMessageDispatcher() const
-  {
-    return dispatcher_;
-  }
+  BtMessageDispatcher* getBtMessageDispatcher() const { return dispatcher_; }
 
-  BtRequestFactory* getBtRequestFactory() const
-  {
-    return requestFactory_;
-  }
+  BtRequestFactory* getBtRequestFactory() const { return requestFactory_; }
 
-  BtMessageFactory* getBtMessageFactory() const
-  {
-    return messageFactory_;
-  }
+  BtMessageFactory* getBtMessageFactory() const { return messageFactory_; }
+
+  bool isMetadataGetMode() const { return metadataGetMode_; }
 
-  bool isMetadataGetMode() const
-  {
-    return metadataGetMode_;
-  }
 public:
-  AbstractBtMessage(uint8_t id, const std::string& name);
+  AbstractBtMessage(uint8_t id, const char* name);
 
   virtual ~AbstractBtMessage();
 
-  virtual bool isSendingInProgress() {
-    return sendingInProgress_;
-  }
+  virtual bool isInvalidate() CXX11_OVERRIDE { return invalidate_; }
 
-  void setSendingInProgress(bool sendingInProgress) {
-    sendingInProgress_ = sendingInProgress;
-  }
+  void setInvalidate(bool invalidate) { invalidate_ = invalidate; }
 
-  virtual bool isInvalidate() {
-    return invalidate_;
-  }
+  virtual bool isUploading() CXX11_OVERRIDE { return uploading_; }
 
-  void setInvalidate(bool invalidate) {
-    invalidate_ = invalidate;
-  }
+  void setUploading(bool uploading) { uploading_ = uploading; }
 
-  virtual bool isUploading() {
-    return uploading_;
-  }
+  cuid_t getCuid() const { return cuid_; }
 
-  void setUploading(bool uploading) {
-    uploading_ = uploading;
-  }
+  void setCuid(cuid_t cuid) { cuid_ = cuid; }
 
-  cuid_t getCuid() const {
-    return cuid_;
-  }
+  const std::shared_ptr<Peer>& getPeer() const { return peer_; }
 
-  void setCuid(cuid_t cuid) {
-    cuid_ = cuid;
-  }
+  void setPeer(const std::shared_ptr<Peer>& peer);
 
-  const SharedHandle<Peer>& getPeer() const
+  virtual void doReceivedAction() CXX11_OVERRIDE {}
+
+  virtual void validate() CXX11_OVERRIDE;
+
+  virtual void onQueued() CXX11_OVERRIDE {}
+
+  virtual void onAbortOutstandingRequestEvent(
+      const BtAbortOutstandingRequestEvent& event) CXX11_OVERRIDE
   {
-    return peer_;
   }
 
-  void setPeer(const SharedHandle<Peer>& peer);
+  virtual void onCancelSendingPieceEvent(const BtCancelSendingPieceEvent& event)
+      CXX11_OVERRIDE
+  {
+  }
 
-  virtual void doReceivedAction() {}
+  virtual void onChokingEvent(const BtChokingEvent& event) CXX11_OVERRIDE {}
 
-  virtual void validate();
-  
-  virtual void onQueued() {}
+  void setBtMessageValidator(std::unique_ptr<BtMessageValidator> validator);
 
-  virtual void onAbortOutstandingRequestEvent
-  (const BtAbortOutstandingRequestEvent& event) {}
-
-  virtual void onCancelSendingPieceEvent
-  (const BtCancelSendingPieceEvent& event) {}
-
-  virtual void onChokingEvent(const BtChokingEvent& event) {}
-
-  void setBtMessageValidator(const SharedHandle<BtMessageValidator>& validator);
-
-  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
+  void setPieceStorage(PieceStorage* pieceStorage);
 
   void setBtMessageDispatcher(BtMessageDispatcher* dispatcher);
 
@@ -172,19 +136,11 @@ public:
 
   void setBtRequestFactory(BtRequestFactory* factory);
 
-  const std::string& getName() const
-  {
-    return name_;
-  }
+  const char* getName() const { return name_; }
 
-  void enableMetadataGetMode()
-  {
-    metadataGetMode_ = true;
-  }
+  void enableMetadataGetMode() { metadataGetMode_ = true; }
 };
 
-typedef SharedHandle<AbstractBtMessage> AbstractBtMessageHandle;
-
 } // namespace aria2
 
 #endif // D_ABSTRACT_BT_MESSAGE_H
