@@ -44,60 +44,67 @@ class FileAllocationIterator;
 
 class AbstractSingleDiskAdaptor : public DiskAdaptor {
 private:
-  SharedHandle<DiskWriter> diskWriter_;
-  uint64_t totalLength_;
+  std::unique_ptr<DiskWriter> diskWriter_;
+  int64_t totalLength_;
   bool readOnly_;
+
 public:
   AbstractSingleDiskAdaptor();
 
   virtual ~AbstractSingleDiskAdaptor();
 
-  virtual void initAndOpenFile();
+  virtual void initAndOpenFile() CXX11_OVERRIDE;
 
-  virtual void openFile();
+  virtual void openFile() CXX11_OVERRIDE;
 
-  virtual void closeFile();
+  virtual void closeFile() CXX11_OVERRIDE;
 
-  virtual void openExistingFile();
+  virtual void openExistingFile() CXX11_OVERRIDE;
 
   virtual void writeData(const unsigned char* data, size_t len,
-                         off_t offset);
+                         int64_t offset) CXX11_OVERRIDE;
 
-  virtual ssize_t readData(unsigned char* data, size_t len, off_t offset);
+  virtual ssize_t readData(unsigned char* data, size_t len,
+                           int64_t offset) CXX11_OVERRIDE;
 
-  virtual bool fileExists();
+  virtual ssize_t readDataDropCache(unsigned char* data, size_t len,
+                                    int64_t offset) CXX11_OVERRIDE;
 
-  virtual uint64_t size();
+  virtual void writeCache(const WrDiskCacheEntry* entry) CXX11_OVERRIDE;
 
-  virtual void truncate(uint64_t length);
-  
-  virtual SharedHandle<FileAllocationIterator> fileAllocationIterator();
+  virtual bool fileExists() CXX11_OVERRIDE;
+
+  virtual int64_t size() CXX11_OVERRIDE;
+
+  virtual void truncate(int64_t length) CXX11_OVERRIDE;
+
+  virtual std::unique_ptr<FileAllocationIterator>
+  fileAllocationIterator() CXX11_OVERRIDE;
 
   // Make sure that DiskWriter is set before calling this function.
-  virtual void enableReadOnly();
+  virtual void enableReadOnly() CXX11_OVERRIDE;
 
   // Make sure that DiskWriter is set before calling this function.
-  virtual void disableReadOnly();
-    
-  virtual bool isReadOnlyEnabled() const { return readOnly_; }
-  
-  virtual void cutTrailingGarbage();
+  virtual void disableReadOnly() CXX11_OVERRIDE;
+
+  virtual bool isReadOnlyEnabled() const CXX11_OVERRIDE { return readOnly_; }
+
+  virtual void enableMmap() CXX11_OVERRIDE;
+
+  virtual void cutTrailingGarbage() CXX11_OVERRIDE;
 
   virtual const std::string& getFilePath() = 0;
 
-  void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
+  void setDiskWriter(std::unique_ptr<DiskWriter> diskWriter);
 
-  const SharedHandle<DiskWriter>& getDiskWriter() const
+  const std::unique_ptr<DiskWriter>& getDiskWriter() const
   {
     return diskWriter_;
   }
 
-  void setTotalLength(const uint64_t& totalLength);
+  void setTotalLength(int64_t totalLength);
 
-  uint64_t getTotalLength() const
-  {
-    return totalLength_;
-  }
+  int64_t getTotalLength() const { return totalLength_; }
 };
 
 } // namespace aria2
