@@ -32,21 +32,17 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_BITFIELD_MESSAGE_H_
-#define _D_BT_BITFIELD_MESSAGE_H_
+#ifndef D_BT_BITFIELD_MESSAGE_H
+#define D_BT_BITFIELD_MESSAGE_H
 
 #include "SimpleBtMessage.h"
 
 namespace aria2 {
 
-class BtBitfieldMessage;
-
-typedef SharedHandle<BtBitfieldMessage> BtBitfieldMessageHandle;
-
 class BtBitfieldMessage : public SimpleBtMessage {
 private:
-  unsigned char* bitfield_;
-  size_t bitfieldLength_;
+  std::vector<unsigned char> bitfield_;
+
 public:
   BtBitfieldMessage();
 
@@ -56,26 +52,24 @@ public:
 
   static const uint8_t ID = 5;
 
-  static const std::string NAME;
+  static const char NAME[];
 
   void setBitfield(const unsigned char* bitfield, size_t bitfieldLength);
 
-  const unsigned char* getBitfield() const { return bitfield_; }
+  const unsigned char* getBitfield() const { return bitfield_.data(); }
 
-  size_t getBitfieldLength() const { return bitfieldLength_; }
+  size_t getBitfieldLength() const { return bitfield_.size(); }
 
-  static BtBitfieldMessageHandle create
-  (const unsigned char* data, size_t dataLength);
+  static std::unique_ptr<BtBitfieldMessage> create(const unsigned char* data,
+                                                   size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
-  virtual unsigned char* createMessage();
+  virtual std::vector<unsigned char> createMessage() CXX11_OVERRIDE;
 
-  virtual size_t getMessageLength();
-
-  virtual std::string toString() const;
+  virtual std::string toString() const CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_BT_BITFIELD_MESSAGE_H_
+#endif // D_BT_BITFIELD_MESSAGE_H
