@@ -39,22 +39,18 @@
 
 namespace aria2 {
 
-class BtCancelMessage;
-
-typedef SharedHandle<BtCancelMessage> BtCancelMessageHandle;
-
 class BtCancelMessage : public RangeBtMessage {
 public:
-  BtCancelMessage(size_t index = 0, uint32_t begin = 0, size_t length = 0);
+  BtCancelMessage(size_t index = 0, int32_t begin = 0, int32_t length = 0);
 
   static const int8_t ID = 8;
 
-  static const std::string NAME;
+  static const char NAME[];
 
-  static BtCancelMessageHandle create
-  (const unsigned char* data, size_t dataLength);
+  static std::unique_ptr<BtCancelMessage> create(const unsigned char* data,
+                                                 size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
