@@ -42,23 +42,19 @@ namespace aria2 {
 class BtKeepAliveMessage : public SimpleBtMessage {
 private:
   static const size_t MESSAGE_LENGTH = 4;
+
 public:
-  BtKeepAliveMessage():SimpleBtMessage(ID, NAME) {}
+  BtKeepAliveMessage() : SimpleBtMessage(ID, NAME) {}
 
   static const uint8_t ID = 99;
 
   static const char NAME[];
 
-  virtual void doReceivedAction() {}
+  virtual void doReceivedAction() CXX11_OVERRIDE {}
 
-  virtual unsigned char* createMessage();
+  virtual std::vector<unsigned char> createMessage() CXX11_OVERRIDE;
 
-  virtual size_t getMessageLength();
-
-  virtual std::string toString() const
-  {
-    return NAME;
-  }
+  virtual std::string toString() const CXX11_OVERRIDE { return NAME; }
 };
 
 } // namespace aria2
