@@ -37,15 +37,16 @@
 
 namespace aria2 {
 
-DHTNodeLookupEntry::DHTNodeLookupEntry(const SharedHandle<DHTNode>& node):
-  node(node), used(false) {}
+DHTNodeLookupEntry::DHTNodeLookupEntry(const std::shared_ptr<DHTNode>& node)
+    : node(node), used(false)
+{
+}
 
-DHTNodeLookupEntry::DHTNodeLookupEntry():
-  node(0), used(false) {}
+DHTNodeLookupEntry::DHTNodeLookupEntry() : used(false) {}
 
 bool DHTNodeLookupEntry::operator==(const DHTNodeLookupEntry& entry) const
 {
-  return node == entry.node;
+  return *node == *entry.node;
 }
 
 } // namespace aria2
