@@ -115,7 +115,7 @@ public:
   void findAll(OutputIterator out, const std::string& hostname,
                uint16_t port) const
   {
-    std::shared_ptr<CacheEntry> target(new CacheEntry(hostname, port));
+    auto target = std::make_shared<CacheEntry>(hostname, port);
     auto i = entries_.find(target);
     if (i != entries_.end()) {
       (*i)->getAllGoodAddrs(out);
