@@ -41,11 +41,7 @@ namespace aria2 {
 
 class Randomizer {
 public:
-  virtual ~Randomizer() {}
-
-  virtual long int getRandomNumber() = 0;
-
-  virtual long int getMaxRandomNumber() = 0;
+  virtual ~Randomizer() = default;
 
   /**
    * Returns random number in [0, to).
