@@ -791,9 +791,10 @@ void gatherProgress(Dict* entryDict, const std::shared_ptr<RequestGroup>& group,
   gatherProgressCommon(entryDict, group, keys);
 #ifdef ENABLE_BITTORRENT
   if (group->getDownloadContext()->hasAttribute(CTX_ATTR_BT)) {
-    gatherProgressBitTorrent(entryDict, group, bittorrent::getTorrentAttrs(
-                                                   group->getDownloadContext()),
-                             e->getBtRegistry()->get(group->getGID()), keys);
+    gatherProgressBitTorrent(
+        entryDict, group,
+        bittorrent::getTorrentAttrs(group->getDownloadContext()),
+        e->getBtRegistry()->get(group->getGID()), keys);
   }
 #endif // ENABLE_BITTORRENT
   if (e->getCheckIntegrityMan()) {
@@ -1601,7 +1602,7 @@ void changeOption(const std::shared_ptr<RequestGroup>& group,
 #ifdef ENABLE_BITTORRENT
              && !dctx->hasAttribute(CTX_ATTR_BT)
 #endif // ENABLE_BITTORRENT
-                 ) {
+    ) {
       // In case of Metalink
       for (auto& fileEntry : dctx->getFileEntries()) {
         // PREF_OUT is not applicable to Metalink.  We have always
