@@ -213,8 +213,10 @@ int WinTLSSession::closeConnection()
         return rv;
       }
 
-      // Alright data is sent or buffered
-      if (rv - len != 0) {
+      // Ignore error here because we probably don't handle those
+      // errors gracefully.  Just shutdown connection.  If rv is
+      // positive, then data is sent or buffered
+      if (rv > 0 && rv - len != 0) {
         return TLS_ERR_WOULDBLOCK;
       }
     }
@@ -384,8 +386,17 @@ ssize_t WinTLSSession::writeData(const void* data, size_t len)
                 static_cast<char*>(sendRecordBuffers_[1].pvBuffer));
     status_ = ::EncryptMessage(&handle_, 0, &desc, 0);
     if (status_ != SEC_E_OK) {
-      A2_LOG_ERROR(fmt("WinTLS: Failed to encrypt a message! %s",
-                       getLastErrorString().c_str()));
+      if (state_ != st_closing) {
+        A2_LOG_ERROR(fmt("WinTLS: Failed to encrypt a message! %s",
+                         getLastErrorString().c_str()));
+      }
+      else {
+        // On closing state, don't log this message in error level
+        // because it seems that the encryption tends to fail in that
+        // state.
+        A2_LOG_DEBUG(fmt("WinTLS: Failed to encrypt a message! %s",
+                         getLastErrorString().c_str()));
+      }
       state_ = st_error;
       return TLS_ERR_ERROR;
     }
@@ -612,7 +623,7 @@ restart:
     // ... and start sending it
     state_ = st_handshake_write;
   }
-  // Fall through
+    // Fall through
 
   case st_handshake_write_last:
   case st_handshake_write: {
@@ -644,7 +655,7 @@ restart:
     // Have to read one or more response messages.
     state_ = st_handshake_read;
   }
-  // Fall through
+    // Fall through
 
   case st_handshake_read: {
   read:
@@ -764,7 +775,7 @@ restart:
       goto restart;
     }
   }
-  // Fall through
+    // Fall through
 
   case st_handshake_done:
     if (obtainTLSRecordSizes() != 0) {
