@@ -13,13 +13,14 @@
 
 namespace aria2 {
 
-class DHTRoutingTableTest:public CppUnit::TestFixture {
+class DHTRoutingTableTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(DHTRoutingTableTest);
   CPPUNIT_TEST(testAddNode);
   CPPUNIT_TEST(testAddNode_localNode);
   CPPUNIT_TEST(testGetClosestKNodes);
   CPPUNIT_TEST_SUITE_END();
+
 public:
   void setUp() {}
 
@@ -30,21 +31,19 @@ public:
   void testGetClosestKNodes();
 };
 
-
 CPPUNIT_TEST_SUITE_REGISTRATION(DHTRoutingTableTest);
 
 void DHTRoutingTableTest::testAddNode()
 {
-  SharedHandle<DHTNode> localNode(new DHTNode());
+  auto localNode = std::make_shared<DHTNode>();
   DHTRoutingTable table(localNode);
-  SharedHandle<MockDHTTaskFactory> taskFactory(new MockDHTTaskFactory());
-  table.setTaskFactory(taskFactory);
-  SharedHandle<MockDHTTaskQueue> taskQueue(new MockDHTTaskQueue());
-  table.setTaskQueue(taskQueue);
+  auto taskFactory = make_unique<MockDHTTaskFactory>();
+  table.setTaskFactory(taskFactory.get());
+  auto taskQueue = make_unique<MockDHTTaskQueue>();
+  table.setTaskQueue(taskQueue.get());
   uint32_t count = 0;
-  for(int i = 0; i < 100; ++i) {
-    SharedHandle<DHTNode> node(new DHTNode());
-    if(table.addNode(node)) {
+  for (int i = 0; i < 100; ++i) {
+    if (table.addNode(std::make_shared<DHTNode>())) {
       ++count;
     }
   }
@@ -53,57 +52,61 @@ void DHTRoutingTableTest::testAddNode()
 
 void DHTRoutingTableTest::testAddNode_localNode()
 {
-  SharedHandle<DHTNode> localNode(new DHTNode());
+  auto localNode = std::make_shared<DHTNode>();
   DHTRoutingTable table(localNode);
-  SharedHandle<MockDHTTaskFactory> taskFactory(new MockDHTTaskFactory());
-  table.setTaskFactory(taskFactory);
-  SharedHandle<MockDHTTaskQueue> taskQueue(new MockDHTTaskQueue());
-  table.setTaskQueue(taskQueue);
+  auto taskFactory = make_unique<MockDHTTaskFactory>();
+  table.setTaskFactory(taskFactory.get());
+  auto taskQueue = make_unique<MockDHTTaskQueue>();
+  table.setTaskQueue(taskQueue.get());
 
-  SharedHandle<DHTNode> newNode(new DHTNode(localNode->getID()));
+  auto newNode = std::make_shared<DHTNode>(localNode->getID());
   CPPUNIT_ASSERT(!table.addNode(newNode));
 }
 
-static void createID(unsigned char* id, unsigned char firstChar, unsigned char lastChar)
+namespace {
+void createID(unsigned char* id, unsigned char firstChar,
+              unsigned char lastChar)
 {
   memset(id, 0, DHT_ID_LENGTH);
   id[0] = firstChar;
-  id[DHT_ID_LENGTH-1] = lastChar;
+  id[DHT_ID_LENGTH - 1] = lastChar;
 }
+} // namespace
 
 void DHTRoutingTableTest::testGetClosestKNodes()
 {
   unsigned char id[DHT_ID_LENGTH];
   createID(id, 0x81, 0);
-  SharedHandle<DHTNode> localNode(new DHTNode(id));
+  auto localNode = std::make_shared<DHTNode>(id);
 
   DHTRoutingTable table(localNode);
 
-  SharedHandle<DHTNode> nodes1[8];
-  SharedHandle<DHTNode> nodes2[8];
-  SharedHandle<DHTNode> nodes3[8];
-  for(size_t i = 0; i < DHTBucket::K; ++i) {
+  std::shared_ptr<DHTNode> nodes1[8];
+  std::shared_ptr<DHTNode> nodes2[8];
+  std::shared_ptr<DHTNode> nodes3[8];
+  for (size_t i = 0; i < DHTBucket::K; ++i) {
     createID(id, 0xf0, i);
-    nodes1[i].reset(new DHTNode(id));
+    nodes1[i] = std::make_shared<DHTNode>(id);
     CPPUNIT_ASSERT(table.addNode(nodes1[i]));
   }
-  for(size_t i = 0; i < DHTBucket::K; ++i) {
+  for (size_t i = 0; i < DHTBucket::K; ++i) {
     createID(id, 0x80, i);
-    nodes2[i].reset(new DHTNode(id));
+    nodes2[i] = std::make_shared<DHTNode>(id);
     CPPUNIT_ASSERT(table.addNode(nodes2[i]));
   }
-  for(size_t i = 0; i < DHTBucket::K; ++i) {
+  for (size_t i = 0; i < DHTBucket::K; ++i) {
     createID(id, 0x70, i);
-    nodes3[i].reset(new DHTNode(id));
+    nodes3[i] = std::make_shared<DHTNode>(id);
     CPPUNIT_ASSERT(table.addNode(nodes3[i]));
   }
   {
     createID(id, 0x80, 0x10);
-    std::vector<SharedHandle<DHTNode> > nodes;
+    std::vector<std::shared_ptr<DHTNode>> nodes;
     table.getClosestKNodes(nodes, id);
     CPPUNIT_ASSERT_EQUAL((size_t)8, nodes.size());
-    for(size_t i = 0; i < nodes.size(); ++i) {
-      CPPUNIT_ASSERT(memcmp(nodes2[0]->getID(), nodes[0]->getID(), DHT_ID_LENGTH) == 0);
+    for (size_t i = 0; i < nodes.size(); ++i) {
+      CPPUNIT_ASSERT(
+          memcmp(nodes2[0]->getID(), nodes[0]->getID(), DHT_ID_LENGTH) == 0);
     }
   }
 }
