@@ -369,11 +369,10 @@ void RpcMethodTest::testAddTorrent()
     CPPUNIT_ASSERT_EQUAL(e_->getOption()->get(PREF_DIR) +
                              "/aria2-0.8.2.tar.bz2",
                          group->getFirstFilePath());
-    CPPUNIT_ASSERT_EQUAL((size_t)1,
-                         group->getDownloadContext()
-                             ->getFirstFileEntry()
-                             ->getRemainingUris()
-                             .size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, group->getDownloadContext()
+                                        ->getFirstFileEntry()
+                                        ->getRemainingUris()
+                                        .size());
     CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/aria2-0.8.2.tar.bz2"),
                          group->getDownloadContext()
                              ->getFirstFileEntry()
@@ -1288,7 +1287,9 @@ void RpcMethodTest::testGetSessionInfo()
 void RpcMethodTest::testPause()
 {
   std::vector<std::string> uris{
-      "http://url1", "http://url2", "http://url3",
+      "http://url1",
+      "http://url2",
+      "http://url3",
   };
   option_->put(PREF_FORCE_SEQUENTIAL, A2_V_TRUE);
   std::vector<std::shared_ptr<RequestGroup>> groups;
