@@ -3,29 +3,30 @@
 #include <cppunit/extensions/HelperMacros.h>
 
 #include "util.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
-class TimeSeedCriteriaTest:public CppUnit::TestFixture {
+class TimeSeedCriteriaTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(TimeSeedCriteriaTest);
   CPPUNIT_TEST(testEvaluate);
   CPPUNIT_TEST_SUITE_END();
-  
+
 public:
   void testEvaluate();
 };
 
-
 CPPUNIT_TEST_SUITE_REGISTRATION(TimeSeedCriteriaTest);
 
-void TimeSeedCriteriaTest::testEvaluate() {
-  TimeSeedCriteria cri(1);
-  // Seel 2seconds. 1 seconds are not enough in some systems.
-  util::sleep(2);
+void TimeSeedCriteriaTest::testEvaluate()
+{
+  TimeSeedCriteria cri(1_s);
+  global::wallclock().reset();
+  global::wallclock().advance(2_s);
   CPPUNIT_ASSERT(cri.evaluate());
   cri.reset();
-  cri.setDuration(10);
+  cri.setDuration(10_s);
   CPPUNIT_ASSERT(!cri.evaluate());
 }
 
